import java.awt.*;
import java.awt.event.*;
import java.io.IOException;

public class MemoPad extends CloseableFrame
{
   private MemoDatabase database;

   private FieldPanel   fieldPanel;
   private ButtonPanel  buttonPanel;
   private MessagePanel messagePanel;

   public MemoPad()
   {
      // initialize( new DefaultMemoDatabase() );
      initialize( null );
   }

   public MemoPad( MemoDatabase db )
   {
      initialize( db );
   }

   public void insert()
   {
      MemoAssociation memo = fieldPanel.currentKeyValuePair();
      if ( !database.insert( memo ) )
         messagePanel.setMessage( memo.key() + " already used." );
      else
         messagePanel.setMessage( memo.key() + " : " + memo.value() );
   }

   public void find()
   {
      String value = database.find( fieldPanel.currentKey() );
      if ( value == null )
         messagePanel.setMessage( "Key not found." );
      else
      {
         fieldPanel.setValue( value );
         messagePanel.setMessage( fieldPanel.currentKey() + " : " + value );
      }
   }

   public void remove()
   {
      fieldPanel.setValue( "" );
      if ( database.remove( fieldPanel.currentKey() ) )
      {
         messagePanel.setMessage( fieldPanel.currentKey() + " removed." );
         fieldPanel.setKey( "" );
      }
      else
         messagePanel.setMessage( "Key not found." );
   }

   public void load()
   {
        String filename = fieldPanel.currentKey();

        try {
            database.load( filename );
            messagePanel.setMessage( "Data loaded from file." );
        } catch (IOException e) {
            messagePanel.setMessage( "An error occurred during load." );
        }
   }

    public void save()
    {
        String filename = fieldPanel.currentKey();

        try {
            database.save( filename );
            messagePanel.setMessage( "Data saved to file." );
        } catch (IOException e) {
            messagePanel.setMessage( "An error occurred during save." );
        }
    }

   /*
    *  helper methods
    */

   private void initialize( MemoDatabase db )
   {
      database = db;

      setLayout( new GridLayout( 3, 1 ) );
      setSize( 300, 140 );
      setTitle( "Memo Pad " );

      fieldPanel = new FieldPanel();
      fieldPanel.setSize( 300, 80 );
      add( fieldPanel );

      buttonPanel = new ButtonPanel( this );
      buttonPanel.setSize( 300, 30 );
      add( buttonPanel );

      messagePanel = new MessagePanel(
                         "............ No messages ............" );
      messagePanel.setSize( 300, 30 );
      add( messagePanel );
   }
}
